summaryrefslogtreecommitdiffstats
path: root/kdecore/krootprop.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/krootprop.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/krootprop.cpp')
-rw-r--r--kdecore/krootprop.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kdecore/krootprop.cpp b/kdecore/krootprop.cpp
index 2d545f30b..4e62b77d7 100644
--- a/kdecore/krootprop.cpp
+++ b/kdecore/krootprop.cpp
@@ -118,7 +118,7 @@ void KRootProp::setProp( const TQString& rProp )
{
// parse the string for first key-value pair separator '\n'
- i = s.find("\n");
+ i = s.tqfind("\n");
if(i == -1)
i = s.length();
@@ -131,7 +131,7 @@ void KRootProp::setProp( const TQString& rProp )
keypair.simplifyWhiteSpace();
- i = keypair.find( "=" );
+ i = keypair.tqfind( "=" );
if( i != -1 )
{
key = keypair.left( i );
@@ -160,7 +160,7 @@ void KRootProp::destroy()
TQString KRootProp::readEntry( const TQString& rKey,
const TQString& pDefault ) const
{
- if( propDict.contains( rKey ) )
+ if( propDict.tqcontains( rKey ) )
return propDict[ rKey ];
else
return pDefault;
@@ -217,18 +217,18 @@ TQColor KRootProp::readColorEntry( const TQString& rKey,
// Support #ffffff style color naming.
// Help ease transistion from legacy KDE setups
- if( aValue.find("#") == 0 ) {
+ if( aValue.tqfind("#") == 0 ) {
aRetColor.setNamedColor( aValue );
return aRetColor;
}
// Parse "red,green,blue"
- // find first comma
- int nIndex1 = aValue.find( ',' );
+ // tqfind first comma
+ int nIndex1 = aValue.tqfind( ',' );
if( nIndex1 == -1 )
return aRetColor;
- // find second comma
- int nIndex2 = aValue.find( ',', nIndex1+1 );
+ // tqfind second comma
+ int nIndex2 = aValue.tqfind( ',', nIndex1+1 );
if( nIndex2 == -1 )
return aRetColor;
@@ -246,9 +246,9 @@ TQColor KRootProp::readColorEntry( const TQString& rKey,
TQString KRootProp::writeEntry( const TQString& rKey, const TQString& rValue )
{
dirty = true;
- if ( propDict.contains( rKey ) ) {
+ if ( propDict.tqcontains( rKey ) ) {
TQString aValue = propDict[ rKey ];
- propDict.replace( rKey, rValue );
+ propDict.tqreplace( rKey, rValue );
return aValue;
}
else {
@@ -280,7 +280,7 @@ TQString KRootProp::writeEntry( const TQString& rKey, const TQColor& rColor )
TQString KRootProp::removeEntry(const TQString& rKey)
{
- if (propDict.contains(rKey)) {
+ if (propDict.tqcontains(rKey)) {
dirty = true;
TQString aValue = propDict[rKey];
propDict.remove(rKey);